# RepoForge — Generated artifacts index
**Tech stack:** Python
**Layers:** main

## Skills
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/SKILL.md`
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/harness/SKILL.md`
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/docs_prompts/SKILL.md`
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/test_ripgrep/SKILL.md`
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/ripgrep/SKILL.md`
- `/home/runner/work/repoforge/repoforge/.claude/skills/main/scenarios_real/SKILL.md`

## Agents
- `/home/runner/work/repoforge/repoforge/.claude/agents/main-agent/AGENT.md`
- `/home/runner/work/repoforge/repoforge/.claude/agents/orchestrator/AGENT.md`

## Skill Registry
- `/home/runner/work/repoforge/repoforge/.atl/skill-registry.md`

## Usage
In Claude Code, skills and agents in `.claude/` are loaded automatically.
In OpenCode, use `.opencode/` — same structure.
Skill registry at `.atl/skill-registry.md` is read by sub-agents automatically.
